pub struct AyRegChange {
pub time: FTs,
pub reg: AyRegister,
pub val: u8,
}Expand description
A type for recording timestamped changes to one of AY-3-8910 audio registers.
Instances of this type are being used by Ay3_891xAudio for sound generation. See also AyRegRecorder.
Fields
time: FTsA timestamp in CPU cycles (T-states), relative to the beginning of the current frame.
reg: AyRegisterWhich register is being changed.
val: u8A new value loaded into the register.
NOTE: may contain bits set to 1 that are unused by the indicated register.
Implementations
Sourceimpl AyRegChange
impl AyRegChange
Sourcepub const fn new(time: FTs, reg: AyRegister, val: u8) -> Self
pub const fn new(time: FTs, reg: AyRegister, val: u8) -> Self
Creates a new AyRegChange from the given arguments.
Sourcepub fn new_from_ts<T: Into<FTs>>(timestamp: T, reg: AyRegister, val: u8) -> Self
pub fn new_from_ts<T: Into<FTs>>(timestamp: T, reg: AyRegister, val: u8) -> Self
Creates a new AyRegChange from the given arguments, converting a provided timestamp first.