ZxInterface1BusDevice

Struct ZxInterface1BusDevice 

pub struct ZxInterface1BusDevice<R, W, N, D: BusDevice> {
    pub microdrives: ZxMicrodrives<D::Timestamp>,
    pub serial: Rs232Io<D::Timestamp, R, W>,
    pub network: ZxNet<D::Timestamp, N>,
    /* private fields */
}
Connects the ZX Interface 1 I/O port emulator as a BusDevice.

Rs232Io’s io::Read as R and io::Write as W implementations are needed to complete this type. ZxNetSocket implementation is needed as N for the underlying ZxNet.

Fields

microdrives: ZxMicrodrives<D::Timestamp>

Direct access to the Microdrives.

serial: Rs232Io<D::Timestamp, R, W>

Direct access to the RS-232 implementation.

network: ZxNet<D::Timestamp, N>

Direct access to the ZX NET implementation.