Module parallel

Module parallel 

Parallel port device designed for parallel printer but other devices can be also emulated.

Structs

NullParallelPort
A parallel port device that does nothing and provides a constant low BUSY signal.
ParallelPortWriter
Emulates a parallel port device with a custom writer.

Traits

ParallelPortDevice
An interface for emulating communication between a Spectrum’s or other peripherals’ hardware port and remote parallel devices.