pub struct ParallelPortWriter<T, W> {
pub writer: W,
/* private fields */
}Expand description
Emulates a parallel port device with a custom writer.
Fields
writer: WTrait Implementations
Sourceimpl<T: Clone, W: Clone> Clone for ParallelPortWriter<T, W>
impl<T: Clone, W: Clone> Clone for ParallelPortWriter<T, W>
Sourcefn clone(&self) -> ParallelPortWriter<T, W>
fn clone(&self) -> ParallelPortWriter<T, W>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Default, W: Default> Default for ParallelPortWriter<T, W>
impl<T: Default, W: Default> Default for ParallelPortWriter<T, W>
Sourcefn default() -> ParallelPortWriter<T, W>
fn default() -> ParallelPortWriter<T, W>
Returns the “default value” for a type. Read more
Sourceimpl<'de, T, W> Deserialize<'de> for ParallelPortWriter<T, W>
impl<'de, T, W> Deserialize<'de> for ParallelPortWriter<T, W>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T: TimestampOps, W: Write> ParallelPortDevice for ParallelPortWriter<T, W>
impl<T: TimestampOps, W: Write> ParallelPortDevice for ParallelPortWriter<T, W>
type Timestamp = T
Sourcefn write_data(&mut self, data: u8, timestamp: Self::Timestamp)
fn write_data(&mut self, data: u8, timestamp: Self::Timestamp)
A device receives a byte written to the parallel data port.
Sourcefn write_strobe(&mut self, strobe: bool, timestamp: Self::Timestamp) -> bool
fn write_strobe(&mut self, strobe: bool, timestamp: Self::Timestamp) -> bool
A device receives a changed
STROBE bit status.
strobe is true if the STROBE went high, false when it went low. Read moreSourcefn poll_busy(&mut self) -> bool
fn poll_busy(&mut self) -> bool
This method is being called once every frame, near the end of it, and should return a
BUSY signal state.
Returns true if the BUSY signal is high, and false when it’s low.Sourcefn next_frame(&mut self, eof_timestamp: T)
fn next_frame(&mut self, eof_timestamp: T)
Called when the current frame ends to allow emulators to wrap stored timestamps.