KeypadKeys

Struct KeypadKeys 

pub struct KeypadKeys { /* private fields */ }
Every key’s state is encoded as a single bit on this 20-bit flag type.

  • Bit = 1 a key is being pressed.
  • Bit = 0 a key is not being pressed.

Implementations

Source

impl KeypadKeys

pub const ROW1_MASK: Self

The 1st (top) physical keypad row’s mask.

pub const ROW2_MASK: Self

The 2nd physical keypad row’s mask.

pub const ROW3_MASK: Self

The 3rd physical keypad row’s mask.

pub const ROW4_MASK: Self

The 4th physical keypad row’s mask.

pub const ROW5_MASK: Self

The 5th (bottom) physical keypad row’s mask.

pub const DOT: Self

pub const PERIOD: Self

An alias of DOT.

pub const N0: Self

pub const SHIFT: Self

An alias of N0.

pub const ENTER: Self

pub const N3: Self

pub const N2: Self

pub const N1: Self

pub const RPAREN: Self

pub const TOGGLE: Self

An alias of RPAREN

pub const LPAREN: Self

pub const ASTERISK: Self

pub const MULTIPLY: Self

An alias of ASTERISK

pub const SLASH: Self

pub const DIVIDE: Self

An alias of SLASH

pub const MINUS: Self

pub const CMND: Self

An alias of MINUS

pub const N9: Self

pub const N8: Self

pub const N7: Self

pub const PLUS: Self

pub const N6: Self

pub const N5: Self

pub const N4: Self

pub const fn empty() -> Self

Returns an empty set of flags.

pub const fn all() -> Self

Returns the set containing all flags.

pub const fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> Self

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

Safety

The caller of the bitflags! macro can chose to allow or disallow extra bits for their bitflags type.

The caller of from_bits_unchecked() has to ensure that all bits correspond to a defined flag or that extra bits are valid for this bitflags type.

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: Self) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: Self) -> bool

Returns true if all of the flags in other are contained within self.

pub fn insert(&mut self, other: Self)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: Self)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: Self)

Toggles the specified flags in-place.

pub fn set(&mut self, other: Self, value: bool)

Inserts or removes the specified flags depending on the passed value.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection between the flags in self and other.

Specifically, the returned set contains only the flags which are present in both self and other.

This is equivalent to using the & operator (e.g. ops::BitAnd), as in flags & other.

pub const fn union(self, other: Self) -> Self

Returns the union of between the flags in self and other.

Specifically, the returned set contains all flags which are present in either self or other, including any which are present in both (see Self::symmetric_difference if that is undesirable).

This is equivalent to using the | operator (e.g. ops::BitOr), as in flags | other.

pub const fn difference(self, other: Self) -> Self

Returns the difference between the flags in self and other.

Specifically, the returned set contains all flags present in self, except for the ones present in other.

It is also conceptually equivalent to the “bit-clear” operation: flags & !other (and this syntax is also supported).

This is equivalent to using the - operator (e.g. ops::Sub), as in flags - other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference between the flags in self and other.

Specifically, the returned set contains the flags present which are present in self or other, but that are not present in both. Equivalently, it contains the flags present in exactly one of the sets self and other.

This is equivalent to using the ^ operator (e.g. ops::BitXor), as in flags ^ other.

pub const fn complement(self) -> Self

Returns the complement of this set of flags.

Specifically, the returned set contains all the flags which are not set in self, but which are allowed for this type.

Alternatively, it can be thought of as the set difference between Self::all() and self (e.g. Self::all() - self)

This is equivalent to using the ! operator (e.g. ops::Not), as in !flags.