pub struct SerialKeypad<T> { /* private fields */ }Expand description
The ZX Spectrum 128 extension keypad.
For the history of this rare and often omitted in emulators device see: Spectrum128Keypad.htm.
+-------+ +-------+ +-------+ +-------+
| DEL ← | | ↑ | | DEL → | |TOGGLE |
| / | | * | | ( | | ) |
+-------+ +-------+ +-------+ +-------+
+-------+ +-------+ +-------+ +-------+
| ← | | ↓ | | → | | CMND |
| 7 | | 8 | | 9 | | - |
+-------+ +-------+ +-------+ +-------+
+-------+ +-------+ +-------+ +-------+
|<< DEL | |>> DEL | |↑↑ | |↑↑ |
| 4 | | 5 | | 6 | | + |
+-------+ +-------+ +-------+ +-------+
+-------+ +-------+ +-------+ +-------+
||<< DEL| |>>| DEL| |⭱⭱ | | E |
| 1 | | 2 | | 3 | | N |
+-------+ +-------+ +-------+ | T |
| E |
+------------------+ +-------+ | R |
| SHIFT | |⭳⭳ | | |
| 0 | | . | | = |
+------------------+ +-------+ +-------+The extension keypad communicates with Spectrum using a unique protocol over the computer’s serial connector.
This type implements SerialPortDevice bringing the extension keypad to its virtual existence.
To change the keypad state use methods directly on the implementation of this type.
Implementations
Sourceimpl<T> SerialKeypad<T>
impl<T> SerialKeypad<T>
Sourcepub fn get_key_state(&self) -> KeypadKeys
pub fn get_key_state(&self) -> KeypadKeys
Reads the current state of the keypad.
Sourcepub fn set_key_state(&mut self, keys: KeypadKeys)
pub fn set_key_state(&mut self, keys: KeypadKeys)
Sets the state of the keypad.