ZxPrinterDevice

Struct ZxPrinterDevice 

pub struct ZxPrinterDevice<T, S> {
    pub spooler: S,
    pub bit_delay: u16,
    /* private fields */
}
This type implements a communication protocol of the ZX Printer.

A data port is being used with the following bits for reading:

  • bit 6 is 0 if the printer is there, 1 if it is not, and is used solely to check if the printer is connected.
  • bit 0 is 1 if the printer is ready for the next bit or 0 if it’s busy printing.
  • bit 7 is 1 if the printer is ready for the new line or 0 if it’s not there yet.

and for writing:

  • bit 7 - a value of 1 activates a stylus, a dot will be printed in this instance. When a 0 is written, the stylus is being deactivated.
  • bit 2 - a value of 1 stops the printer motor and when a 0 is written it starts the printer motor.
  • bit 1 - a value of 1 slows the printer motor, a value of 0 sets a normal motor speed.

An implementation of a Spooler trait is required as a generic parameter S to complete this type.

There’s also a dedicated bus device implementation to be used solely with the ZxPrinterDevice.

Fields

spooler: S

An instance of the Spooler trait implementation type.

bit_delay: u16

Can be changed to adjust speed. The default is 855 T-states (~16 dot lines / sec.).

Implementations

Source

impl<T: TimestampOps, S: Spooler> ZxPrinterDevice<T, S>

pub fn next_frame(&mut self, eof_timestamp: T)

This method should be called after each emulated frame.

pub fn reset(&mut self)

This method should be called when the device is being reset.

pub fn write_control(&mut self, data: u8, timestamp: T)

This method should be called when a CPU writes to the ZX Printer port.

pub fn read_status(&mut self, timestamp: T) -> u8

This method should be called when a CPU reads from the ZX Printer port.